@@ -396,8 +396,4 @@ class Vn:
         df2['cartesian_join_key'] = 1
         result = pd.merge(df1, df2, on ='cartesian_join_key').drop(labels="cartesian_join_key", axis=1)
         return result
-        
-vn = Vn()
-with open(os.path.join(os.pardir, "credentials.json")) as file:
-    credentials = json.load(file)
-vn.authenticate(**credentials['VeevaNetwork'][0])
\ No newline at end of file
+        
\ No newline at end of file
